@@ -57,7 +57,6 @@ merge metadata and data-matrix of samples/datasets in a cohort and edit or delet
         cohort_name: str,
         description: str,
         repo_key=None,
-        entity_id=None,
         dataset_id=None,
         sample_id=None,
     ) -> None:
@@ -107,14 +106,11 @@ cohort.
         if repo_key:
             self.add_to_cohort(
                 repo_key=repo_key,
-                entity_id=entity_id,
                 dataset_id=dataset_id,
                 sample_id=sample_id,
             )
 
-    def add_to_cohort(
-        self, repo_key=None, entity_id=None, dataset_id=None, sample_id=None
-    ) -> None:
+    def add_to_cohort(self, repo_key: str, dataset_id=None, sample_id=None) -> None:
         """
         This function is used to add datasets or samples to a cohort.
 
@@ -141,12 +137,8 @@ instantiated.
         self.bridge_obj._cohort_details = self._cohort_details
         if self._cohort_details is None:
             raise InvalidCohortOperationException
-        if not (
-            (repo_key and entity_id)
-            or (repo_key and dataset_id and sample_id)
-            or (repo_key and dataset_id)
-        ):
-            raise InvalidParameterException("repo_key entity_id dataset_id sample_id")
+        if not ((repo_key and dataset_id and sample_id) or (repo_key and dataset_id)):
+            raise InvalidParameterException("repo_key dataset_id sample_id")
         repo_name = self.bridge_obj._return_omixatlas_name(repo_key)
         if repo_name not in self._cohort_info:
             raise InvalidRepoException(repo_name)
@@ -166,7 +158,7 @@ instantiated.
             self.bridge_obj.add_to_cohort_single(
                 self._cohort_path,
                 repo_name=repo_name,
-                entity_id=entity_id,
+                entity_id=dataset_id,
                 entity_type=cohort_entity_type,
             )
         else:
@@ -179,7 +171,7 @@ instantiated.
             )
         self._cohort_details = self.bridge_obj._cohort_details
 
-    def remove_from_cohort(self, entity_id: list) -> None:
+    def remove_from_cohort(self, dataset_id=None, sample_id=[]) -> None:
         """
         This function is used for removing datasets or samples from a cohort.
 
@@ -205,13 +197,13 @@ instantiated.
             raise InvalidCohortOperationException
         if "entity_type" not in self._cohort_details:
             raise EmptyCohortException
-        if not (entity_id and isinstance(entity_id, list)):
-            raise InvalidParameterException("entity_id")
         entity_type = self._cohort_details.get("entity_type")
         if entity_type == "dataset":
-            self.core_obj.remove_single_from_cohort(self._cohort_path, entity_id)
+            self.core_obj.remove_single_from_cohort(self._cohort_path, dataset_id)
         else:
-            self.core_obj.remove_multiple_from_cohort(self._cohort_path, entity_id)
+            self.core_obj.remove_multiple_from_cohort(
+                self._cohort_path, dataset_id, sample_id
+            )
         self._cohort_details = self.core_obj._cohort_details
 
     def merge_data(self, data_level: str):
