@@ -34,8 +34,10 @@ IMAGE_URL_ENDPOINT = (
 # statuscodes
 OK = 200
 CREATED = 201
+COMPUTE_ENV_VARIABLE = "POLLY_TYPE"
 
 # cohort constants
+COHORT_VERSION = "0.2"
 COHORT_CONSTANTS_URL = (
     "https://elucidatainc.github.io/PublicAssets/cohort_constants.txt"
 )
