@@ -5,6 +5,7 @@ from polly import helpers
 from pathlib import Path
 import logging
 import pandas as pd
+import collections
 from polly.errors import (
     InvalidCohortOperationException,
     InvalidParameterException,
@@ -84,7 +85,7 @@ class CohortFileStandard:
         folder_name = os.path.basename(cohort_path)
         cohort_name = folder_name.split(".")[0]
         meta_dict["cohort_name"] = cohort_name
-        meta_details = ["description", "number_of_samples"]
+        meta_details = ["description", "number_of_datasets"]
         for key, value in self._cohort_details.items():
             if key.lower() in meta_details:
                 meta_dict[key] = value
@@ -114,6 +115,7 @@ class CohortFileStandard:
             "datatype": [],
             "dataset_id": [],
             "sample_id": [],
+            "number_of_samples": [],
         }
         dataset_list = list(self._cohort_details["entity_id"].keys())
         for entity in dataset_list:
@@ -128,6 +130,7 @@ class CohortFileStandard:
             df_dict["source_omixatlas"].append(omixatlas)
             df_dict["datatype"].append(data_type)
             df_dict["sample_id"].append(sample_id)
+            df_dict["number_of_samples"].append(len(sample_id))
         dataframe = pd.DataFrame.from_dict(df_dict)
         return dataframe
 
@@ -350,7 +353,7 @@ class CohortFileStandard:
                 return False
         return True
 
-    def remove_single_from_cohort(self, cohort_path: str, entity_id: list) -> None:
+    def remove_single_from_cohort(self, cohort_path: str, dataset_id: list) -> None:
         """
         This function is used for removing dataset_id(s) from a cohort
         Args:
@@ -358,20 +361,20 @@ class CohortFileStandard:
         Returns:
             | A confirmation message on removal of dataset_id or sample_id from cohort.
         """
-        if not (entity_id and isinstance(entity_id, list)):
-            raise InvalidParameterException("entity_id")
+        if not (dataset_id and isinstance(dataset_id, list)):
+            raise InvalidParameterException("dataset_id")
         dataset_count = 0
         verified_dataset = []
         file_meta = helpers.make_path(cohort_path, "cohort.meta")
-        entity_id = list(set(entity_id))
+        dataset_id = list(set(dataset_id))
         json_data = None
         with open(file_meta, "r+b") as openfile:
             byte = openfile.read()
             data = base64.b64decode((byte))
             json_data = json.loads(data.decode("utf-8"))
-            dataset_id = list(json_data["entity_id"].keys())
-            for dataset in entity_id:
-                if dataset not in dataset_id:
+            dataset_id_metadata = list(json_data["entity_id"].keys())
+            for dataset in dataset_id:
+                if dataset not in dataset_id_metadata:
                     logging.basicConfig(level=logging.INFO)
                     logging.info(f"Dataset Id - {dataset} not present in the Cohort.")
                     continue
@@ -391,7 +394,7 @@ class CohortFileStandard:
                     empty_keys.append(key)
             for key in empty_keys:
                 del omixatlas_dict[key]
-            json_data["number_of_samples"] -= dataset_count
+            json_data["number_of_datasets"] -= dataset_count
             json_data["source_omixatlas"] = omixatlas_dict
             if not bool(json_data.get("entity_id")):
                 if "entity_type" in json_data:
@@ -405,7 +408,7 @@ class CohortFileStandard:
         logging.info(f"'{dataset_count}' dataset/s removed from Cohort!")
         self._cohort_details = json_data
 
-    def remove_multiple_from_cohort(self, cohort_path, entity_id: list):
+    def remove_multiple_from_cohort(self, cohort_path, dataset_id: str, sample_id=[]):
         """
         This function is used for removing dataset_id or sample_id from a cohort
         Args:
@@ -413,51 +416,74 @@ class CohortFileStandard:
         Returns:
             | A confirmation message on removal of dataset_id or sample_id from cohort.
         """
-        dataset_count = 0
-        verified_dataset = []
+        if not (dataset_id and isinstance(dataset_id, str)):
+            raise InvalidParameterException("dataset_id")
         file_meta = helpers.make_path(cohort_path, "cohort.meta")
-        entity_id = list(set(entity_id))
         json_data = None
         with open(file_meta, "r+b") as openfile:
             byte = openfile.read()
             data = base64.b64decode((byte))
             json_data = json.loads(data.decode("utf-8"))
-            dataset_id = list(json_data["entity_id"].keys())
-            for dataset in entity_id:
-                if dataset not in dataset_id:
-                    logging.basicConfig(level=logging.INFO)
-                    logging.info(f"Dataset Id - {dataset} not present in the Cohort.")
-                    continue
-                dataset_count += 1
-                verified_dataset.append(dataset)
-                omixatlas = json_data.get("entity_id", {}).get(dataset)[0]
-                gct_path = f"{cohort_path}/{omixatlas}_{dataset}.gct"
-                json_path = f"{cohort_path}/{omixatlas}_{dataset}.jpco"
-                os.remove(gct_path)
-                os.remove(json_path)
-                del json_data.get("entity_id")[dataset]
-                json_data.get("source_omixatlas").get(omixatlas).pop(dataset)
-            omixatlas_dict = json_data.get("source_omixatlas")
-            empty_keys = []
-            for key, value in omixatlas_dict.items():
-                if value == {}:
-                    empty_keys.append(key)
-            for key in empty_keys:
-                del omixatlas_dict[key]
-            json_data["number_of_samples"] -= dataset_count
-            json_data["source_omixatlas"] = omixatlas_dict
-            if not bool(json_data.get("entity_id")):
-                if "entity_type" in json_data:
-                    del json_data["entity_type"]
-            input = json.dumps(json_data)
-            encoded_data = base64.b64encode(input.encode("utf-8"))
-            openfile.seek(0)
-            openfile.write(encoded_data)
-            openfile.truncate()
-        logging.basicConfig(level=logging.INFO)
-        logging.info(f"'{dataset_count}' dataset/s removed from Cohort!")
+            dataset_id_metadata = list(json_data["entity_id"].keys())
+            if dataset_id not in dataset_id_metadata:
+                logging.basicConfig(level=logging.INFO)
+                logging.info(f"Dataset Id - {dataset_id} not present in the Cohort.")
+            else:
+                source_omixatlas = json_data.get("source_omixatlas")
+                omixatlas = json_data.get("entity_id", {}).get(dataset_id)[0]
+                list_of_samples = source_omixatlas.get(omixatlas, {}).get(dataset_id)
+                if len(sample_id) > 0:
+                    sample_id = list(set(sample_id))
+                    new_list_of_samples = [
+                        x for x in list_of_samples if x not in sample_id
+                    ]
+                    if len(new_list_of_samples) != 0:
+                        if collections.Counter(
+                            new_list_of_samples
+                        ) == collections.Counter(list_of_samples):
+                            print("Invalid Samples to remove! ")
+                        else:
+                            json_data.get("source_omixatlas").get(omixatlas, {})[
+                                dataset_id
+                            ] = new_list_of_samples
+                            print("Samples removed successfully!")
+                    else:
+                        json_data = self._remove_dataset(
+                            dataset_id, json_data, cohort_path
+                        )
+                else:
+                    json_data = self._remove_dataset(dataset_id, json_data, cohort_path)
+                input = json.dumps(json_data)
+                encoded_data = base64.b64encode(input.encode("utf-8"))
+                openfile.seek(0)
+                openfile.write(encoded_data)
+                openfile.truncate()
         self._cohort_details = json_data
 
+    def _remove_dataset(self, dataset_id: str, json_data: dict, cohort_path: str):
+        omixatlas = json_data.get("entity_id", {}).get(dataset_id)[0]
+        gct_path = f"{cohort_path}/{omixatlas}_{dataset_id}.gct"
+        json_path = f"{cohort_path}/{omixatlas}_{dataset_id}.jpco"
+        os.remove(gct_path)
+        os.remove(json_path)
+        del json_data.get("entity_id")[dataset_id]
+        json_data.get("source_omixatlas").get(omixatlas).pop(dataset_id)
+        omixatlas_dict = json_data.get("source_omixatlas")
+        empty_keys = []
+        for key, value in omixatlas_dict.items():
+            if value == {}:
+                empty_keys.append(key)
+        for key in empty_keys:
+            del omixatlas_dict[key]
+        json_data["number_of_datasets"] -= 1
+        json_data["source_omixatlas"] = omixatlas_dict
+        if not bool(json_data.get("entity_id")):
+            if "entity_type" in json_data:
+                del json_data["entity_type"]
+        logging.basicConfig(level=logging.INFO)
+        logging.info(" 1 dataset removed from Cohort!")
+        return json_data
+
     def _update_metadata_single(
         self, repo_name, entity_type, dataset_id, deleted_id, file_meta, dataset_tuple
     ):
@@ -475,7 +501,7 @@ class CohortFileStandard:
                 [source_omixatlas[repo_name].append(i) for i in dataset_id]
             for i in range(0, len(dataset_id)):
                 json_data["entity_id"][dataset_id[i]] = dataset_tuple[i]
-                json_data["number_of_samples"] += 1
+                json_data["number_of_datasets"] += 1
             input = json.dumps(json_data)
             encoded_data = base64.b64encode(input.encode("utf-8"))
             openfile.seek(0)
@@ -521,7 +547,7 @@ class CohortFileStandard:
             source_omixatlas.get(repo_name, {})[dataset_id] = list_of_samples
             json_data["entity_id"][dataset_id] = dataset_tuple
             if download_flag:
-                json_data["number_of_samples"] += 1
+                json_data["number_of_datasets"] += 1
             json_data["source_omixatlas"] = source_omixatlas
             input = json.dumps(json_data)
             encoded_data = base64.b64encode(input.encode("utf-8"))
