@@ -81,9 +81,76 @@ class InvalidPathException(Exception):
         return "This path does not represent a file or a directory. Please try again."
 
 
+class InvalidCohortPathException(Exception):
+    def __str__(self):
+        return "This path does not represent a Cohort. Please try again."
+
+
+class InvalidCohortNameException(Exception):
+    def __str__(self, cohort_name):
+        return f"The identifier {cohort_name} does not represent a valid cohort name. Please try again."
+
+
+class InvalidRepoException(Exception):
+    def __init__(self, repo_name):
+        self.repo_name = repo_name
+
+    def __str__(self):
+        return f"The repository : {self.repo_name} is not supported. Please contact Polly Support."
+
+
+class InvalidDatasetException(Exception):
+    def __str__(self):
+        return "Dataset/s not added."
+
+
+class InvalidCohortOperationException(Exception):
+    def __str__(self):
+        return "This operation is not valid as no cohort has been instantiated."
+
+
+class EmptyCohortException(Exception):
+    def __str__(self):
+        return "There are no datasets in the cohort. Please try adding datasets using add_to_cohort() function."
+
+
+class CohortEditException(Exception):
+    def __str__(self):
+        return "No parameter specified for editing in cohort"
+
+
+class InvalidCohortMergeOperation(Exception):
+    def __str__(self):
+        return "Incorrect or blank parameter specified for merging in cohort"
+
+
+class InvalidCohortAddition(Exception):
+    def __str__(self):
+        return "The repository type is not compatible with the cohort due to different file structure. Please try again."
+
+
+class OutdatedCohortVersion(Exception):
+    def __init__(self, version):
+        self.version = version
+
+    def __str__(self):
+        return f"The Cohort version is outdated. Please try again with the new version VERSION-{self.version}."
+
+
+class TechnicalFaultException(Exception):
+    def __str__(self):
+        return "Samples not downloaded due to a technical fault. Please check \
+            the arguments passed and try again. Contact Polly Support in case of repeated failure."
+
+
+class InvalidDatatypeException(Exception):
+    def __str__(self):
+        return "Single Cell Datatype is not incorporated. Please contact Polly Support."
+
+
 class MissingKeyException(Exception):
     def __init__(self, key):
-        self.reason = key
+        self.key = key
 
     def __str__(self):
         return f"Missing keys {self.key}"
@@ -99,7 +166,7 @@ class InvalidParameterException(Exception):
 
 class InvalidFormatException(Exception):
     def __str__(self):
-        return "File format not supported."
+        return "This file format is not supported."
 
 
 class paramException(BaseExceptionError):
@@ -129,6 +196,13 @@ class apiErrorException(BaseExceptionError):
             self.detail = detail
 
 
+class invalidDataException(BaseExceptionError):
+    def __init__(self, title=None, detail=None):
+        self.title = app_err_info.INCORRECT_DATA
+        if detail:
+            self.detail = detail
+
+
 class invalidApiResponseException(BaseExceptionError):
     def __init__(self, title=None, detail=None):
         if title:
@@ -161,7 +235,6 @@ def extract_json_api_error(response):
     error = response.json().get("error")
     if error is None:
         error = response.json().get("errors")[0]
-
     title = error.get("title")
     detail = error.get("detail")
     return title, detail
