@@ -5,7 +5,6 @@ import logging
 import os
 import platform
 import tempfile
-import csv
 from pathlib import Path
 from typing import Union, Dict
 from collections import namedtuple
@@ -526,20 +525,18 @@ converter functions.
         Return all the columns from the csv file
         whose datatype is array
         """
-        columns_in_csv = []
-        with open(local_file_path) as f:
-            reader = csv.reader(f)
-            columns_in_csv = next(reader)
-            dict_reader = csv.DictReader(f, delimiter=",", fieldnames=columns_in_csv)
+        with open(local_file_path, "rb"):
+            df = pd.read_csv(local_file_path)
+            columns_in_csv = list(df.columns)
             conv_columns = []
-            for row in dict_reader:
-                for index in range(0, len(columns_in_csv)):
-                    key = columns_in_csv[index]
-                    val = row[key]
-                    if re.search(r"\[(.*?)\]", val):
-                        conv_columns.append(key)
-                    elif val == "[]":
-                        conv_columns.append(key)
+            for index, row in df.iterrows():
+                for col in columns_in_csv:
+                    value = row[col]
+                    if isinstance(value, str):
+                        if re.search(r"\[(.*?)\]", value):
+                            conv_columns.append(col)
+                        elif value == "[]":
+                            conv_columns.append(col)
                 break
         return columns_in_csv, conv_columns
 
